@@ -3,6 +3,7 @@
 from django.conf import settings
 
 import djconfig
+from djconfig.models import Config as ConfigModel
 
 __all__ = ['DjConfigLocMemMiddleware', ]
 
@@ -14,10 +15,19 @@ class DjConfigLocMemMiddleware(object):
     """
     def process_request(self, request):
         self.check_backend()
-        djconfig.load()
+        self.reload()
 
     def check_backend(self):
         backend = settings.CACHES[djconfig.BACKEND]
 
         if not backend['BACKEND'].endswith(".LocMemCache"):
-            raise ValueError("DjConfigLocMemMiddleware requires LocMemCache as cache")
\ No newline at end of file
+            raise ValueError("DjConfigLocMemMiddleware requires LocMemCache as cache")
+
+    def reload(self):
+        """
+        This reloads the cache *only* if the database has changed.
+        """
+        data = dict(ConfigModel.objects.filter(key="_updated_at").values_list('key', 'value'))
+
+        if data.get('_updated_at') != djconfig.config._updated_at:
+            djconfig.load()
\ No newline at end of file
